<?php declare(strict_types=1);

namespace Infomaker\Everyware\Twig;

use Twig_Environment;

/**
 * Environment
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Twig
 * @since   Infomaker\Everyware\Twig\Environment 0.1
 */
class Environment extends Twig_Environment
{

    /**
     * Loads a specific template and compiles it. If cache is on, save the compiled class in cac3he to be evaluated
     * later on.
     *
     * @param string $name
     * @param int|null $index
     *
     * @return \Twig_Template
     * @throws \Twig_Error_Loader
     * @throws \Twig_Error_Runtime
     * @throws \Twig_Error_Syntax
     */
    public function loadTemplate($name, $index = null): \Twig_Template
    {
        $cls = $mainCls = $this->getTemplateClass($name);

        if (isset($this->loadedTemplates[$cls])) {
            return $this->loadedTemplates[$cls];
        }
        
        if ($this->getCache() instanceof objectCacheSystem && ! class_exists($cls, false)) {
            // Fetch template from cache and load
            $this->getCache()->load($this->getCache()->generateKey($name, $mainCls));
        }

        return parent::loadTemplate($name, $index);
    }
}
