<?php
namespace Infomaker\Everyware\Twig\Tests\Features\General;

use PHPUnit\Framework\TestCase;
use PHPUnit\Framework\MockObject\Generator;
use Behat\Behat\Context\SnippetAcceptingContext;
use Infomaker\Everyware\Twig\View;
use Infomaker\Everyware\Twig\FilesystemLoader;
use Infomaker\Everyware\Twig\Tests\Features\Traits\ViewSetupCommon;


/**
 * This is a behat test class, using Gherkin descriptions.
 * Further explanation of what is being tested and method descriptions can be found in the .feature files.
 * 
 * --!! IMPORTANT DO NOT CHANGE THE DOC BLOCKS !!--
 */
class GeneralContext implements SnippetAcceptingContext
{
    use ViewSetupCommon;
    private $everyTwig;
    
    /**
     * @Then I can init EveryTwig with debug option :debug
     */
    public function everyTwig_can_be_initiated_with_options($debug)
    {
        $methods = [
            'getCache',
            'getPathCacheKey',
            'setCache'
        ];

        $options = [
            'debug' => $debug === 'false' ? false : true,
        ];
        
        $env = $this->viewSetup->getEveryTwig()->init((new Generator())->getMock(FilesystemLoader::class, $methods), [], [], $options);
        TestCase::assertSame($env->isDebug(), $options['debug']);
    }
    /**
     * @Then a view(:template) can be generated with :namespace and :testText
     */
    public function a_view_can_be_rendered($template, $namespace, $testText)
    {
        $this->everyTwig = $this->viewSetup->getEveryTwig();
        $view = View::generate('@' . $namespace . '/' . $template);
        TestCase::assertNotNull($view);
        TestCase::assertContains($testText, $view);
        TestCase::assertInternalType('string', $view);
    }
}